#!/usr/bin/perl -w

#use lib './lib';

use XML::Malware;
use Data::Dumper;



my $h;
$h->{'company'} = 'wes co';
$h->{'author'} = 'wes';
$h->{'comment'} = 'test';
$h->{'timestamp'} = '2009-02-23T17:34:56';
$h->{'id'} = '';

push(@{$h->{'objects'}->{'file'}}, { id => '',  md5 => "aa31da6402d850ce94e7c19bc97effe1" });
push(@{$h->{'objects'}->{'classification'}}, { id => '', companyName => 'some company', type => 'dirty', classificationName => 'className'});

my $m = XML::Malware->new($h);

warn $m->out();
